fetch_and_load_xml

Function fetch_and_load_xml 

pub async fn fetch_and_load_xml<F, Fut>(read_mem: F) -> Result<String, XmlError>
where F: FnMut(u64, usize) -> Fut, Fut: Future<Output = Result<Vec<u8>, XmlError>>,
Fetch the GenICam XML document using the provided memory reader closure.

The closure must return the requested number of bytes starting at the provided address. It can internally perform chunked transfers.

Reads GevFirstURL, falling back to GevSecondURL when the first URL is empty or its document cannot be retrieved. ZIP-compressed XML documents are decompressed transparently.